@@ -1,6 +1,6 @@
 /* vi:set et ai sw=2 sts=2 ts=2: */
 /*-
- * Copyright (c) 2009 Jannis Pohlmann <jannis@xfce.org>
+ * Copyright (c) 2009-2011 Jannis Pohlmann <jannis@xfce.org>
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public
@@ -103,21 +103,21 @@ tumbler_cache_get_thumbnail (TumblerCache           *cache,
 
 
 void
-tumbler_cache_cleanup (TumblerCache *cache,
-                       const gchar  *uri_prefix,
-                       guint64       since)
+tumbler_cache_cleanup (TumblerCache       *cache,
+                       const gchar *const *base_uris,
+                       guint64             since)
 {
   g_return_if_fail (TUMBLER_IS_CACHE (cache));
   g_return_if_fail (TUMBLER_CACHE_GET_IFACE (cache)->cleanup != NULL);
 
-  (TUMBLER_CACHE_GET_IFACE (cache)->cleanup) (cache, uri_prefix, since);
+  (TUMBLER_CACHE_GET_IFACE (cache)->cleanup) (cache, base_uris, since);
 }
 
 
 
 void
-tumbler_cache_delete (TumblerCache *cache,
-                      const GStrv   uris)
+tumbler_cache_delete (TumblerCache       *cache,
+                      const gchar *const *uris)
 {
   g_return_if_fail (TUMBLER_IS_CACHE (cache));
   g_return_if_fail (uris != NULL);
@@ -129,14 +129,13 @@ tumbler_cache_delete (TumblerCache *cache,
 
 
 void
-tumbler_cache_copy (TumblerCache *cache,
-                    const GStrv   from_uris,
-                    const GStrv   to_uris)
+tumbler_cache_copy (TumblerCache       *cache,
+                    const gchar *const *from_uris,
+                    const gchar *const *to_uris)
 {
   g_return_if_fail (TUMBLER_IS_CACHE (cache));
   g_return_if_fail (from_uris != NULL);
   g_return_if_fail (to_uris != NULL);
-  g_return_if_fail (g_strv_length (from_uris) == g_strv_length (to_uris));
   g_return_if_fail (TUMBLER_CACHE_GET_IFACE (cache)->copy != NULL);
 
   (TUMBLER_CACHE_GET_IFACE (cache)->copy) (cache, from_uris, to_uris);
@@ -145,14 +144,13 @@ tumbler_cache_copy (TumblerCache *cache,
 
 
 void
-tumbler_cache_move (TumblerCache *cache,
-                    const GStrv   from_uris,
-                    const GStrv   to_uris)
+tumbler_cache_move (TumblerCache       *cache,
+                    const gchar *const *from_uris,
+                    const gchar *const *to_uris)
 {
   g_return_if_fail (TUMBLER_IS_CACHE (cache));
   g_return_if_fail (from_uris != NULL);
   g_return_if_fail (to_uris != NULL);
-  g_return_if_fail (g_strv_length (from_uris) == g_strv_length (to_uris));
   g_return_if_fail (TUMBLER_CACHE_GET_IFACE (cache)->move != NULL);
 
   (TUMBLER_CACHE_GET_IFACE (cache)->move) (cache, from_uris, to_uris);
